@@ -1,7 +1,7 @@
 package Perinci::CmdLine::dux::I18N;
 use parent 'Perinci::CmdLine::I18N';
 
-our $VERSION = '1.36'; # VERSION
+our $VERSION = '1.37'; # VERSION
 
 1;
 # ABSTRACT: Project class for Perinci::CmdLine::dux
@@ -18,7 +18,7 @@ Perinci::CmdLine::dux::I18N - Project class for Perinci::CmdLine::dux
 
 =head1 VERSION
 
-version 1.36
+version 1.37
 
 =head1 DESCRIPTION
 
@@ -33,12 +33,12 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-dux>.
 
 =head1 SOURCE
 
-Source repository is at L<HASH(0x44c43f8)>.
+Source repository is at L<https://github.com/sharyanto/perl-App-dux>.
 
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://rt.cpan.org/Public/Dist/Display.html?Name=App-dux
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-dux>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
